==> mongodb-5.0.32.gh.tar.gz: mongo-r5.0.32/src/mongo/client/replica_set_monitor_protocol_test_util.cpp <==
/**
 *    Copyright (C) 2020-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */
#include "mongo/platform/basic.h"

#include "mongo/client/replica_set_monitor_protocol_test_util.h"
#include "mongo/util/assert_util.h"

namespace mongo {
void ReplicaSetMonitorProtocolTestUtil::setRSMProtocol(ReplicaSetMonitorProtocol protocol) {
    const BSONObj newParameterObj = BSON(kRSMProtocolFieldName << toString(protocol));
    BSONObjIterator parameterIterator(newParameterObj);
    BSONElement newParameter = parameterIterator.next();
    const auto foundParameter = findRSMProtocolServerParameter();

    uassertStatusOK(foundParameter->second->set(newParameter));
}

void ReplicaSetMonitorProtocolTestUtil::resetRSMProtocol() {
    const auto defaultParameter = kDefaultParameter[kRSMProtocolFieldName];
    const auto foundParameter = findRSMProtocolServerParameter();

    uassertStatusOK(foundParameter->second->set(defaultParameter));
}

ServerParameter::Map::const_iterator
ReplicaSetMonitorProtocolTestUtil::findRSMProtocolServerParameter() {
    const ServerParameter::Map& parameterMap = ServerParameterSet::getGlobal()->getMap();
    invariant(parameterMap.size());
    return parameterMap.find(kRSMProtocolFieldName);
}

}  // namespace mongo

==> mongodb-6.0.25.gh.tar.gz: mongo-r6.0.25/src/mongo/client/replica_set_monitor_protocol_test_util.cpp <==
/**
 *    Copyright (C) 2020-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */
#include "mongo/platform/basic.h"

#include "mongo/client/replica_set_monitor_protocol_test_util.h"
#include "mongo/util/assert_util.h"

namespace mongo {
void ReplicaSetMonitorProtocolTestUtil::setRSMProtocol(ReplicaSetMonitorProtocol protocol) {
    const BSONObj newParameterObj = BSON(kRSMProtocolFieldName << toString(protocol));
    BSONObjIterator parameterIterator(newParameterObj);
    BSONElement newParameter = parameterIterator.next();
    const auto foundParameter = findRSMProtocolServerParameter();

    uassertStatusOK(foundParameter->second->set(newParameter));
}

void ReplicaSetMonitorProtocolTestUtil::resetRSMProtocol() {
    const auto defaultParameter = kDefaultParameter[kRSMProtocolFieldName];
    const auto foundParameter = findRSMProtocolServerParameter();

    uassertStatusOK(foundParameter->second->set(defaultParameter));
}

ServerParameter::Map::const_iterator
ReplicaSetMonitorProtocolTestUtil::findRSMProtocolServerParameter() {
    const auto& parameterMap = ServerParameterSet::getNodeParameterSet()->getMap();
    invariant(parameterMap.size());
    return parameterMap.find(kRSMProtocolFieldName);
}

}  // namespace mongo
